@@ -479,10 +479,7 @@ class CfgSetup:
             self.savepath = self.path / SAVE.get('path', 'results')
         self.savefile = SAVE.get('filename', 'tmp') + '.hdf5'
         self.comp = SAVE.get('compression', 'None')
-        try:
-            self.probes = json.loads(SAVE.get('probes', '[]'))
-        except:
-            raise ValueError('probe and probe_location have been merged. Update config file.')
+        self.probes = json.loads(SAVE.get('probes', '[]'))
 
         # Check probes
         if self.probes:
@@ -514,3 +511,6 @@ class CfgSetup:
         self.show_pml = FIGS.getboolean('pml', True)
         self.bc_profiles = FIGS.getboolean('bc_profiles', True)
         self.fps = FIGS.getint('fps', 24)
+        self.xlim = json.loads(FIGS.get('xlim', '[]'))
+        self.ylim = json.loads(FIGS.get('ylim', '[]'))
+
