@@ -51,10 +51,10 @@ class Vorticity:
 
         # dvz/dx
         for sub in self.msh.dxdomains:
-            sub.du(self.fld.rv/self.fld.r, self.fld.E, *sub.ix, *sub.iz)
+            sub.du(self.fld.rv/self.fld.r, self.fld.E, *sub.ix, *sub.iz, sub.bsize)
 
         # dvx/dz
         for sub in self.msh.dzdomains:
-            sub.du(self.fld.ru/self.fld.r, self.fld.F, *sub.ix, *sub.iz)
+            sub.du(self.fld.ru/self.fld.r, self.fld.F, *sub.ix, *sub.iz, sub.bsize)
 
         self.fld.vxz = self.fld.E - self.fld.F
